#Archiving New Naturals

##towards a context-aware global material commons: what's in *your* local archive?

![](../images/pics-insta3.jpg)*Building a local archive, Loes Bogers, 2020*

**The goal of this project was to explore and develop simple methods for open archiving of socalled "new naturals"\*. The outcomes are developed to work toward a collaborative, global - but context-aware - material archive....**

- that is not only ecologically, but also historically, culturally, geographically aware;
- that can extend material activism beyond bioplastics alone;
- highlights what a material *does*: its properties and its sensorial qualities in text, tags and (moving) image.
- that promotes an open-source attitude to the development of design materials, and credits the work done by others before you;
- that acknowledges all those practical questions: from buying the right kind of ingredients, all the way to tips and tricks for that challenging phase of controlled drying and curing materials to its "final" form;
- that is explained in layman's terms, demystifying ingredients and processes without oversimplifying them;
- imaging collaborative open archiving that can facilitate critique, contestations, suggestions, updates and reviews from peers;
- offering a package that allows novices to learn, and educators to get started in a systematic way...
- ... and encourages experienced material designers and "alchemists" to continue asking the hard critical questions regarding sustainability, resource and waste streams and share those considerations with each recipe or ingredient.

\* *note: "new" or "other" naturals is not a thing (yet). But the word is sometimes used in material archives as container category for materials that don't fit the traditional material families of wood, hide, metal, glass, plastics, stone, etcetera. New or other naturals is a left-over tag to indicate composite or otherwise hybrid materials made from renewable natural resources such as food waste, plant fibres etcetera.* 

![](../images/pics-insta1.jpg)*Working on a recipe, Loes Bogers, 2020*

##Outcomes

The outcomes of the selection are threefold: 1) a number of documentation tools and templates, in an effort to ask new questions when developing processes and combining materials; 2) a curated recipe selection from best practices in labs all over the world, that offer a comprehensive starting point for exploring "new naturals" in e.g. (informal) learning contexts; and 3) suggestions for structuring and building on this knowledge in open, collaborative ways, with critical considerations of technical, sensorial as well as cultural, historical and ecological aspects. 

###1. Tools and templates for documenting "new naturals"

- [**a manifesto for archiving new naturals**](../outcomes/new_naturals_manifesto), comprised of a list of considerations I've come to find very helpful in thinking about the archiving practices of new naturals;
- [**a video tutorial**](../outcomes/tools_and_templates/tactilityvideo/) for capturing the tactile experience of material samples
- [**a template to document recipes**](../outcomes/tools_and_templates/recipe_template/), to help you capture the entire process, while asking the hard contextual questions and document relevant considerations when developing new recipes and consideration applications and scale. Colleague fabricademer Beatriz Sandini tested and used the templates to document the recipes of her project [Ephemeral Fashion Lab](https://class.textile-academy.org/2020/beatriz.sandini/projects/0-final-project/). 
- [**a template to document ingredients**](../outcomes/tools_and_templates/ingredient_template/), helping you ask the hard questions and document relevant considerations for adopting new ingredients and additives, also in terms of upscaling.
- [**templates for labels**](../outcomes/tools_and_templates/label_templates/) to create your own physical archive with material samples (building on the work of Maria Viftrup who designed the original sample label designs for TextileLab Waag).


![](../images/pics-insta2.jpg)*Measuring and logging shrinkage, Loes Bogers, 2020*


###2. Core recipes for starting your own *new naturals* sample archive

Making material samples myself was the core part of the research process. It required making these (and actually many more) recipes, and trying to craft different physical forms to arrive at the important questions that need to be asked and documented. Questions such as: when do you demould a bioplastic? How long does it take before it reached its final form and doesn't shrink anymore? Where does this recipe even come from? What makes a material sustainable? If it is sustainable, what other arguments might there be that make a material contested or controversial to use? 

As a result of that process of making, wondering and questioning, [a selection of 24 foundational recipes](../outcomes/24_core_recipes/) is documented here, showing the research process, but also allowing anyone to start a physical sample archive with "new natural" materials. All these materials are easily and harmlessly absorbed by nature within 90 days and/or can be turned into compost, *without* controlled conditions assuming industrial facilities. And/or the material can be re-used with no or little additional resources. Biodegradability as a sustainability label is too often used to greenwash e.g. disposable packaging materials, so these criteria were chosen as point of departure.

Three additional criteria were used to make the selection: it should be based on local abundance (ingredients sourced and/or produced around my location. Secondly, it should include a range of techniques, and lastly, these techniques should result in a variety of physical forms to accommodate makers and designers from different fields from product design as well as textiles and fashion. 

**Selected based on local abundance**

Since this project was developed in the Netherlands, the consideration was to take local abundance as a starting point for any physical archive of material samples. The samples made for this project will be used at the Amsterdam University of Applied Sciences to help design students explore new natural materials through making. so it seems fitting to set the example of starting by looking for *local waste streams* to source ingredients, supplemented with ingredients that are *locally produced* as much as possible (ideally within the Netherlands or in neighbouring countries, alternatively within Europe). This also means that starting a physical sample archive elsewhere could and maybe *should* look different! What will be *your* list of 24 recipes using resources abundant in your location?


**A variety of biofabrication techniques**

The collection contains different techniques in biofabration to give a novice material designer a wide range of methods to explore the potential of the natural resources around them. I want to stress that these recipes are not my inventions, nor are they new. They are my personal variations at best, and this part of the work is heavily indebted to the knowledge collected and created in and around the Fabricademy network and other design and DIY biology communities, and also builds upon the (physical) Material Archive at Textile Lab Waag that was realised by Cecilia Raspanti, Maria Viftrup and others in 2016-2017. Where it was known and identifyable, the related work and cultural origins of the techniques are referenced in each recipe. Techniques include: 

- ***polymerization by cooking*** e.g. bioplastics
- ***curing*** bioplastics with natural compounds (e.g. calcification of algae-based plastic)
- ***extracting*** natural pigments in the form of inks and dyes
- ***growing*** microbial cultures for leather alternatives and bacterial dyes
- ***crystallization*** of minerals
- ***re-use*** of biodegradable plastics such as PLA
- and examples of how all of the above may be combined by means of making ***composite materials***

**A variety of physical forms**

Secondly, the selection of 24 *techniques* is made based on the extent to which they allow material makers to craft a variety of *physical forms*. Considering which forms a material can take is equally a part of material learning and exploration, and is a starting point for understanding how they might be processed further by thermoforming, lasercutting, extruding, sewing, welding etcetera. The recipes result in: 

- ***surfaces*** (flat materials, slabs, sheets)
- ***strings*** (that may be used as yarns or for additive manufacturing)
- ***liquids*** (water and alcohol based inks and dyes)
- ***solids*** (including 3D solids but also structurally open spatial forms like moulded composites)
- ***surface treatments*** (e.g. forming crystals on a substrate, direct dyeing with bacteria)

###3. A features wishlist for an online materials repository 

[The design brief for an imagined online archiving system](https://docs.google.com/presentation/d/1YRHikbOnj0WLbVhc2BELcTUBk30rFFGOpYzF1ra7Jp4/edit?usp=sharing)
suggests a system for a context-aware, collaborative materials database. Developing such a system is outside the scope of this project, and connecting to existing initiatives may be a better avenue to explore. The design of the system proposed here: 

- 	**enables peer feedback**, ratings and constructive criticism
-  its logics of organisation and additional required fields can promote and **add a critical angle on the way we consider new naturals** as material alternatives. It allows users to filter on the technical and sensorial properties as well as constituent ingredients *and* other tags pulled from the fields of the recipe and ingredient forms. The questions suggested can lead to considerations and tags that may all become relevant filtering criteria: such as *local abundance* in your area. Most *successful recipes*, or *most contested* ones that could be further researched. 
-  the way the datastructures are linked **allow for analysis of popular recipes and correlations** with geographical regions, environmental conditions and local abundance of certain ingredients
-  the suggested **features may be included in existing archives (preferred)** or be a starting point for a new initiative.

###Future development

The templates and the starter recipes are envisioned as tools that can already contribute to building up local, offline communities who want to explore and become more aware of new natural material alternatives through making. This can be used already in informal learning contexts as well as (higher) education.

Online repositories can facilitate communities of material explorers - from novice to expert - in constructing not only new materials, but also further the critical understanding of the processes and resources involved, and learn from techniques and arguments developed elsewhere. Of course for this to take effect the suggestions need to be realised in an existing database, or a new one might be developed. Future steps involve:  

- **realising the online database** further with a designer and developer or connecting to existing initiatives (preferred)
- research and/or develop and document **methods for DIY material testing**, like testing tensile strength, chemical resistance etc. 
- create well-researched **ingredient pages** for all the ingredients used (for the moment only the entry for [glycerine](../../files/example_glycerine/) is there as an example). 
- possibly add a **section for open-source DIY tools** for fabrication
- **further testing of the formats as tools for learning** in higher education and fabricademy, gathering peer feedback from peers

![](../images/pics-insta4.jpg)*Documenting a recipe, Loes Bogers, 2020*
 
##State of the art 

We are in a moment where more and more designers are starting to recognize the importance of materials and unlearning our wasteful and toxic addictions to plastic and other common design materials. This is a wildly interesting field that can be approached from many perspectives. This project contributes less to the *material engineering* side of materials research, but is more focused on the DIY, open-source approaches to it that can be useful for designers and makers to be used in critical material imaginaries.

Below is a discussion of a small selection from the current state of the art. This project is hugely indebted to each of them and the amazing work the people behind it have done. The critiques here come from a commitment to push the work further and extend the work others did before us. If you feel like your work should be acknowledged here or in the recipes, please contact me at l[dot]bogers[at]hva[dot]nl.

###1. Classifying "new natural" materials

**Material District**

Commercial material archives are committed to showcasing new materials and rethinking ways of presenting material innovations (which can either be high-tech and innovative, or more innovative in the sense of sustainability). [Material District](https://materialdistrict.com/) is a match-making platform for organisations involved in R&D of materials, and design professionals. This organization hosts an annual materials fair in the Netherlands, and hosts an online archive, where new materials are logged together with some technical material properties, and information about manufacturers. New materials can be showcased at a cost of €100 per year. 

Their role in matchmaking R&D with designers and industry is important and pivotal in promoting the uptake of new materials (Damadei, 2019). 

But the classification systems continue to rely on traditional material families like wood, ceramics, and metals, and except for the container category of "other naturals". New and often hybrid materials require us to rethink such categories (Kula & Ternaux 2019: p. 337-338), but new models are still lacking. 

One avenue might be to explore and make explicit the tactile qualities of materials, alongside their technical properties. Material District does this in a summarized way (see image below) that gives an overview of the material that is accessible to novices. Although their online repository is well thought through and comprehensive, the organisation continues to cater to clients need to get a "feel" for the different materials on offer, by organizing visits to their archive and by hosting a materials fair annually. 

![](../images/materialdistrict.jpg)*Properties listed for each material on the Material District Archive, screenshot of their website, 2020*

**Sensory descriptors and categorization**

Besides the inspiration taken from Material District, the archive put forward here incorporates the sensory descriptors and categories proposed by Beatrice Lerma in her article "Materials ecoefficiency and perception. Proceedings" (2010: pp. 1-8). Discussing an existing reference tool called SensoTact, she describes a sensory vocabular to describe materials (e.g. stickiness, rough/smooth, hot/cold) in addition to parameters to evaluate socalled *material eco-compatibility*. [MATto](http://www.matto.design/en/home/), the materials library and consultancy service at the Politecnico di Torino has adopted this approach (but is not open to the public). To describe relative sustainability, Lerma suggests to discuss parameters such as toxicity, energy involved in production, shelf life, and distance to source. 

Material archives used in the context of polytecnic institutes generally take a focus that is more on the technical and engineering qualities of materials, with optical and tactile qualities being secondary: a small element within this much larger technical spectrum. It is argued however these sensorial qualities that can be pivotal in material acceptance and we need methods to account for them (Karana, Barati, Rognoli & Zeeuw van der Laan 2015): rather than organizing materials based on what they *are* (wood, metal, glass and so on) we might consider other systems along the lines of what they can *do* and *elicit* in us. Their work and methods are successfully finding their way into higher education in art and design schools in the Netherlands. What the approach suggested here might offer, is are the prompts that aim to instill a cultural, political and historical awareness of materials and their constintuent compounds.

**Physical forms vs. material families**

In parallel to the traditional materials families (wood, metals, etc) the MATto materials library *also* organizes materials more in line with fabrication methods and physical forms that are recognizable and useful to designers. Users can also navigate the archive by browsing collections put together based on their physical form: e.g. slabs, tubes & pipes, foam and expanded materials, textiles, grilles & nets, surface treatments, gels and pastes, grains/flakes & powders, and so on. This is an interesting approach that allows designers to consider different alternatives for a part of a product. For example someone designing a speaker might browse the "grilles and nets" sections and find composites made with yarns or other fibres she would never find browsing polymers. The physical forms are another method we explore in this project, but in a more simplified manner. User interviews I did during the project showed that these categories were the most meaninful that could capture all: surfaces & surface treatments, solids, powders/grains, liquids/gels, and strings/tubes.

![](../images/matto.jpg)*Phycisal forms and material families alongside one another, Screenshot from their website, 2020*

###2. Physical Material Archives

**Tactile experience of materials**
The ways of categorizing and describing material samples listed above are useful and easy to implement in text-based databases. But can only give a limited feel for the aesthetics and tactility of a material. 

The physical [Material Archive](https://viftrup.com/textilelab) developed at Textile Lab Waag, by Cecilia Raspanti and designed by Maria Viftrup and others from 2016 onwards continues to be one of the most effective ways of offering alternatives to designers. Not only because it offers visitors to meet the materials, and touch, smell and manipulate them, but it also allows them to take them home. Not in the sense that they can take the materials home, but because the recipe and technique to recreate the material is documented on the back of the label attached to the sample. Of course the memory of the tactile experience fades in a way that photographs and words cannot recover. What might be other ways to document tactility?

<iframe src="https://player.vimeo.com/video/243628535" width="640" height="360" frameborder="0" allow="autoplay; fullscreen" allowfullscreen></iframe>
<p><a href="https://vimeo.com/243628535">Material Archive promo - by Maria Viftrup</a> from <a href="https://vimeo.com/waagmakers">Makers of Waag</a> on <a href="https://vimeo.com">Vimeo</a>.</p>

Their archive is divided into "raw" and "made" materials and a loosely organised but effective tagging system to indicate what kind of material a given sample is. The downside here, is that the Material Archive at Textile Lab Waag does not have any kind of online accessible version of the archive, and updating recipes when new insights are formed can be an issue, as a recipe will always be tied to that particular tangible sample. This project hopes to contribute to their efforts by suggesting ways to bring this amazing archive online. 

![](../images/institutemaking.jpg)*The materials library at the Institute of Making, UCL London, Loes Bogers, 2020*

The [Institute of Making](https://www.instituteofmaking.org.uk/) at UCL London has a materials library with another interesting approach that lets go of classification systems altogether. Their exhibition space continuously changes to offer fresh perspectives on materials, and can vary from chronological ordering, or it can be an exhibition around controversial materials. The story is the organizing factor here, and always depends on the availability of staff and slots to visit the archive. They offer a valuable (design-)historical perspective on materials, but do not organize or offer any practical information for manufacturing and manipulating them. 

It is difficult to separate the material from the form however. Most of the "materials" in this library are already *applied*. They have already taken shape as a functional object, which indicates the potential of a material, but it can also make it challenging to disentangle the form and possible functions/shapes/forms. This library contains a lot of materials that would be hard to impossible to recreate without specialist tools and knowledge, but evokes interesting questions as to what tools and (lack of) access to them enable us to do. 


###3. Renewable and DIY: Material Activism

We should also take note of the work other critical designers have done before in the realm of materials research & development. Many designers have develped their own versions of materials, and great applications for them in their design practice. And there are dozens of beautiful big books to showcase them. Although they may create *awareness* and inspiration when it comes to these approaches to design and materials, most often, the exact recipe or process is not disclosed. Even more problematic is that it is very common for a designer to use a crafts or heritage technique and presents it as though it has been their discovery, paying no credit to the cultural history such practices emerged from. Many of the techniques hailed as sustainable material innovatinos are in fact rediscovered old techniques. 

**Open-source material activism**

Miriam Ribul's framing of DIY bioplastics as material activism (2013) that should be open-source is pivotal here. With this open access publication Ribul shares 4 basic recipes for bioplastics that can be created at home with ingredients bought at a super market. She argues for collaborative approaches to radical imaginaries when it comes to the issue of our collective plastic addiction. The focus on *only renewable* ingredient is unique to the approaches listed so far (which may come as a surprise). Such a strict approach, with *only* DIY recipes, and simple, renewable ingredients (which we also see in Materiom, below) is essential when it comes to rethinking materials. We cannot yield to the temptations of high-tech materials alone, but must continue to push for *sustainable* approaches to high-tech only. 

The DIY recipe book is a popular format which we also see in Clara Davis - [*The Secrets of Bioplastic*](https://issuu.com/nat_arc/docs/the_secrets_of_bioplastic_) (2017), Margaret Dunne's [*The Bioplastics Cookbook: A Catalogue of Bioplastics Recipes*](https://issuu.com/nat_arc/docs/bioplastic_cook_book_3) (2018). It demystifies the processes of material design, keeping the form very rudimentary, allows it to stay open to interpretation and further development. Although it opens up a wealth of information with this format, they remain static. How can we make this kind of development ongoing? Another downside to these publications is that they are unlikely to go very in depth in terms of tooling options, drying time, etcetera because there's an incentive to keep recipes short and fit them on a page or a spread. On the other hand that is exactly what makes them accessible.  

Lastly, there seems to be a danger with such recipe books because they often take a narrow focus for the sake of clarity and coherence. As a historical parrallel: the "natural textile dyeing" books from the 1970s would celebrate and appreciate nature's splendor, while including heavy metals and toxic compounds as mordants in their recipes. In a similar way, we see that some recipe books eagerly consider renewable alternative to petrol-based plastics, but don't find it worth mentioning that animal-based products such as gelatine might be an issue as well. 

###4. Collaborative databases 
 
[Materiom](https://materiom.org/) is a great initiative that takes the open-source, DIY, renewable-only approach, and makes efforts to collect and present recipes in a beautifully designed environment that is accessible online. Users can add their own recipes so the archive can continue to grow. Beautiful photography makes these materials very appealing and desirable as a design material as well. 

In the same way that family recipes are contested, and cooks claim to have the "ultimate" recipe to a ragu bolognese, material recipes will be contested. We've seen this in the myriad ways people craft and form materials in the context of this Fabricademy course. Great value could be added if collaborative databases also facilitated debate, contestation and forking of certain recipes. With peer reviews and rating we might be able start to see patterns as to which technique work best for whom. Where are they in the world? What are their environmental conditions and which type of which ingredient are they using? 

A platform like Materiom might also benefit from acknowledging more explicitly where these crafts practices are coming from, and taking a more critical stance as to when something is *more sustainable*. As no material is perfect or without issues, we need more concrete handles for assessing the ethics of using certain materials in particular context or applications. Expanding the amount and type of entry fields required when submitting a new recipe could potentially help the community of "material nerds" deepen their understanding of what they are working with, so material activism extends beyond the ecological, into the social, cultural, political, and technical. 


![](../images/stopmotionstand.jpg)*Shooting a tactility impression for archiving, Loes Bogers, 2020*


##References

- **Materials ecoefficiency and perception** by Beatrice Lerma, in Proceedings: CESB 2010 Prague - Central Europe towards Sustainable Building 'From Theory to Practice', 2010: pp. 1-8.
- **Material Driven Design (MDD): A Method for Design for Material Experiences** by Elvin Karana, Bahar Barati, Valentina Rognoli, Anouk Zeeuw van der Laan, in the International Journal of Design, Vol 9. No 2, 2015: [link](http://www.ijdesign.org/index.php/IJDesign/article/view/1965)
- **Materiology: The Creative Industry’s Guide to Materials and Technologies** by Daniël Kula & Elodie Ternaux, Basel: Birkhäuser, 2014.
- **Institute of Making - Fourth Year Report 2016-2017**, by the Institute of Making, UCL London, 2017: [link](https://www.instituteofmaking.org.uk/about)
- **Recipes for Material Activism** by Miriam Ribul, 2014, via issuu [link](https://issuu.com/miriamribul/docs/miriam_ribul_recipes_for_material_a)
- **Research Book Bioplastics** by Juliette Pepin, 2014, via issuu [link](https://issuu.com/juliettepepin/docs/bookletbioplastic)
- **The Secrets of Bioplastic** by Clara Davis (Fabtex, IAAC, Fab Lab Barcelona), 2017, [link](https://issuu.com/nat_arc/docs/the_secrets_of_bioplastic_).
- **The Bioplastics Cookbook: A Catalogue of Bioplastics Recipes** by Margaret Dunne for Fabtextiles, 2018, [link](https://issuu.com/nat_arc/docs/bioplastic_cook_book_3)
- **DAMADEI: Design & Advanced Materials as a Driver of European Innovation**, by Damadei project committee, funded by the European Commission, 2013.  
- **Material Archive** by TextileLab Waag, Amsterdam (Cecilia Raspanti, Maria Viftrup and others), 2016-ongoing. 



